@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -71,30 +71,169 @@ public class CurrencyNames_hu extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "AED", "AED" },
+            { "AFN", "AFN" },
+            { "ALL", "ALL" },
+            { "AMD", "AMD" },
+            { "ANG", "ANG" },
+            { "AOA", "AOA" },
+            { "ARS", "ARS" },
             { "AUD", "AUD" },
+            { "AWG", "AWG" },
+            { "AZN", "AZN" },
+            { "BAM", "BAM" },
+            { "BBD", "BBD" },
+            { "BDT", "BDT" },
+            { "BGN", "BGN" },
+            { "BHD", "BHD" },
+            { "BIF", "BIF" },
+            { "BMD", "BMD" },
+            { "BND", "BND" },
+            { "BOB", "BOB" },
             { "BRL", "BRL" },
+            { "BSD", "BSD" },
+            { "BTN", "BTN" },
+            { "BWP", "BWP" },
+            { "BYN", "BYN" },
+            { "BYR", "BYR" },
+            { "BZD", "BZD" },
             { "CAD", "CAD" },
+            { "CDF", "CDF" },
+            { "CHF", "CHF" },
+            { "CLP", "CLP" },
             { "CNH", "CNH" },
             { "CNY", "CNY" },
+            { "COP", "COP" },
+            { "CRC", "CRC" },
+            { "CUC", "CUC" },
+            { "CUP", "CUP" },
+            { "CVE", "CVE" },
+            { "CZK", "CZK" },
+            { "DJF", "DJF" },
+            { "DKK", "DKK" },
+            { "DOP", "DOP" },
+            { "DZD", "DZD" },
+            { "EGP", "EGP" },
+            { "ERN", "ERN" },
+            { "ETB", "ETB" },
             { "EUR", "EUR" },
+            { "FJD", "FJD" },
+            { "FKP", "FKP" },
             { "GBP", "GBP" },
+            { "GEL", "GEL" },
+            { "GHS", "GHS" },
+            { "GIP", "GIP" },
+            { "GMD", "GMD" },
+            { "GNF", "GNF" },
+            { "GTQ", "GTQ" },
+            { "GYD", "GYD" },
             { "HKD", "HKD" },
+            { "HNL", "HNL" },
+            { "HRK", "HRK" },
+            { "HTG", "HTG" },
             { "HUF", "Ft" },
+            { "IDR", "IDR" },
             { "ILS", "ILS" },
             { "INR", "INR" },
+            { "IQD", "IQD" },
+            { "IRR", "IRR" },
+            { "ISK", "ISK" },
+            { "JMD", "JMD" },
+            { "JOD", "JOD" },
             { "JPY", "\u00a5" },
+            { "KES", "KES" },
+            { "KGS", "KGS" },
+            { "KHR", "KHR" },
+            { "KMF", "KMF" },
+            { "KPW", "KPW" },
             { "KRW", "KRW" },
-            { "MRU", "MRU" },
+            { "KWD", "KWD" },
+            { "KYD", "KYD" },
+            { "KZT", "KZT" },
+            { "LAK", "LAK" },
+            { "LBP", "LBP" },
+            { "LKR", "LKR" },
+            { "LRD", "LRD" },
+            { "LTL", "LTL" },
+            { "LVL", "LVL" },
+            { "LYD", "LYD" },
+            { "MAD", "MAD" },
+            { "MDL", "MDL" },
+            { "MGA", "MGA" },
+            { "MKD", "MKD" },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
+            { "MRO", "MRO" },
+            { "MUR", "MUR" },
+            { "MVR", "MVR" },
+            { "MWK", "MWK" },
             { "MXN", "MXN" },
+            { "MYR", "MYR" },
+            { "MZN", "MZN" },
+            { "NAD", "NAD" },
+            { "NGN", "NGN" },
+            { "NIO", "NIO" },
+            { "NOK", "NOK" },
+            { "NPR", "NPR" },
             { "NZD", "NZD" },
+            { "OMR", "OMR" },
+            { "PAB", "PAB" },
+            { "PEN", "PEN" },
+            { "PGK", "PGK" },
+            { "PHP", "PHP" },
+            { "PKR", "PKR" },
+            { "PLN", "PLN" },
+            { "PYG", "PYG" },
+            { "QAR", "QAR" },
+            { "RON", "RON" },
+            { "RSD", "RSD" },
+            { "RUB", "RUB" },
+            { "RWF", "RWF" },
+            { "SAR", "SAR" },
+            { "SBD", "SBD" },
+            { "SCR", "SCR" },
+            { "SDG", "SDG" },
+            { "SEK", "SEK" },
+            { "SGD", "SGD" },
+            { "SHP", "SHP" },
+            { "SLL", "SLL" },
+            { "SOS", "SOS" },
+            { "SRD", "SRD" },
+            { "SSP", "SSP" },
+            { "STD", "STD" },
+            { "STN", "STN" },
+            { "SYP", "SYP" },
+            { "SZL", "SZL" },
+            { "THB", "THB" },
+            { "TJS", "TJS" },
+            { "TMT", "TMT" },
+            { "TND", "TND" },
+            { "TOP", "TOP" },
+            { "TRY", "TRY" },
+            { "TTD", "TTD" },
             { "TWD", "TWD" },
+            { "TZS", "TZS" },
+            { "UAH", "UAH" },
+            { "UGX", "UGX" },
             { "USD", "USD" },
+            { "UYU", "UYU" },
+            { "UZS", "UZS" },
+            { "VEF", "VEF" },
+            { "VES", "VES" },
             { "VND", "VND" },
+            { "VUV", "VUV" },
+            { "WST", "WST" },
             { "XCD", "XCD" },
+            { "YER", "YER" },
+            { "ZAR", "ZAR" },
+            { "ZMK", "ZMK" },
+            { "ZMW", "ZMW" },
             { "adp", "Andorrai peseta" },
             { "aed", "EAE-dirham" },
             { "afa", "afg\u00e1n afghani (1927\u20132002)" },
             { "afn", "afg\u00e1n afghani" },
+            { "alk", "alb\u00e1n lek (1946\u20131965)" },
             { "all", "alb\u00e1n lek" },
             { "amd", "\u00f6rm\u00e9ny dram" },
             { "ang", "holland antill\u00e1ki forint" },
@@ -112,13 +251,16 @@ public class CurrencyNames_hu extends OpenListResourceBundle {
             { "azn", "azerbajdzs\u00e1ni manat" },
             { "bad", "Bosznia-hercegovinai d\u00edn\u00e1r (1992\u20131994)" },
             { "bam", "bosznia-hercegovinai konvertibilis m\u00e1rka" },
+            { "ban", "bosznia-hercegovinai \u00faj d\u00edn\u00e1r (1994\u20131997)" },
             { "bbd", "barbadosi doll\u00e1r" },
             { "bdt", "bangladesi taka" },
             { "bec", "Belga frank (konvertibilis)" },
             { "bef", "Belga frank" },
             { "bel", "Belga frank (p\u00e9nz\u00fcgyi)" },
             { "bgl", "Bolg\u00e1r kem\u00e9ny leva" },
+            { "bgm", "bolg\u00e1r szocialista leva" },
             { "bgn", "bolg\u00e1r \u00faj leva" },
+            { "bgo", "bolg\u00e1r leva (1879\u20131952)" },
             { "bhd", "bahreini din\u00e1r" },
             { "bif", "burundi frank" },
             { "bmd", "bermudai doll\u00e1r" },
@@ -137,7 +279,7 @@ public class CurrencyNames_hu extends OpenListResourceBundle {
             { "buk", "Burmai kyat" },
             { "bwp", "botswanai pula" },
             { "byb", "Feh\u00e9rorosz \u00faj rubel (1994\u20131999)" },
-            { "byn", "feh\u00e9rorosz rubel" },
+            { "byn", "belarusz rubel" },
             { "byr", "feh\u00e9rorosz rubel (2000\u20132016)" },
             { "bzd", "belize-i doll\u00e1r" },
             { "cad", "kanadai doll\u00e1r" },
@@ -236,10 +378,12 @@ public class CurrencyNames_hu extends OpenListResourceBundle {
             { "lyd", "l\u00edbiai d\u00edn\u00e1r" },
             { "mad", "marokk\u00f3i dirham" },
             { "maf", "Marokk\u00f3i frank" },
+            { "mdc", "mold\u00e1v kupon" },
             { "mdl", "moldov\u00e1n lei" },
             { "mga", "madagaszk\u00e1ri ariary" },
             { "mgf", "Madagaszk\u00e1ri frank" },
             { "mkd", "macedon d\u00edn\u00e1r" },
+            { "mkn", "maced\u00f3n d\u00e9n\u00e1r (1992\u20131993)" },
             { "mlf", "Mali frank" },
             { "mmk", "mianmari kyat" },
             { "mnt", "mong\u00f3liai tugrik" },
@@ -307,7 +451,7 @@ public class CurrencyNames_hu extends OpenListResourceBundle {
             { "sur", "Szovjet rubel" },
             { "svc", "Salvadori col\u00f3n" },
             { "syp", "sz\u00edriai font" },
-            { "szl", "szv\u00e1zif\u00f6ldi lilangeni" },
+            { "szl", "szv\u00e1zi lilangeni" },
             { "thb", "thai baht" },
             { "tjr", "T\u00e1dzsikiszt\u00e1ni rubel" },
             { "tjs", "t\u00e1dzsikiszt\u00e1ni somoni" },
@@ -335,7 +479,8 @@ public class CurrencyNames_hu extends OpenListResourceBundle {
             { "veb", "Venezuelai bolivar (1871\u20132008)" },
             { "vef", "venezuelai bolivar (2008\u20132018)" },
             { "ves", "venezuelai bolivar" },
-            { "vnd", "vietnami dong" },
+            { "vnd", "vietn\u00e1mi dong" },
+            { "vnn", "vietn\u00e1mi dong (1978\u20131985)" },
             { "vuv", "vanuatui vatu" },
             { "wst", "nyugat-szamoai tala" },
             { "xaf", "CFA frank BEAC" },
@@ -362,6 +507,7 @@ public class CurrencyNames_hu extends OpenListResourceBundle {
             { "yud", "Jugoszl\u00e1v kem\u00e9ny d\u00edn\u00e1r" },
             { "yum", "Jugoszl\u00e1v \u00faj d\u00edn\u00e1r" },
             { "yun", "Jugoszl\u00e1v konvertibilis d\u00edn\u00e1r" },
+            { "yur", "jugoszl\u00e1v reform\u00e1lt din\u00e1r (1992\u20131993)" },
             { "zal", "D\u00e9l-afrikai rand (p\u00e9nz\u00fcgyi)" },
             { "zar", "d\u00e9l-afrikai rand" },
             { "zmk", "Zambiai kwacha (1968\u20132012)" },
