@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -93,6 +93,7 @@ public class LocaleNames_te extends OpenListResourceBundle {
         final String metaValue_th = "\u0c25\u0c3e\u0c2f\u0c4d";
         final String metaValue_tl = "\u0c1f\u0c17\u0c32\u0c3e\u0c17\u0c4d";
         final String metaValue_ban = "\u0c2c\u0c3e\u0c32\u0c3f\u0c28\u0c40\u0c38\u0c4d";
+        final String metaValue_ccp = "\u0c1a\u0c15\u0c4d\u0c2e\u0c3e";
         final String metaValue_cop = "\u0c15\u0c4b\u0c2a\u0c4d\u0c1f\u0c3f\u0c15\u0c4d";
         final String metaValue_nqo = "\u0c28\u0c4d\u0c15\u0c4b";
         final String metaValue_peo = "\u0c2a\u0c4d\u0c30\u0c3e\u0c1a\u0c40\u0c28 \u0c2a\u0c30\u0c4d\u0c37\u0c3f\u0c2f\u0c28\u0c4d";
@@ -108,6 +109,7 @@ public class LocaleNames_te extends OpenListResourceBundle {
             { "mwr", "\u0c2e\u0c3e\u0c30\u0c4d\u0c35\u0c3e\u0c21\u0c3f" },
             { "Tagb", "\u0c1f\u0c3e\u0c17\u0c4d\u0c2c\u0c3e\u0c28\u0c35\u0c3e" },
             { "Zsye", "\u0c0e\u0c2e\u0c4b\u0c1c\u0c3f" },
+            { "ccp", metaValue_ccp },
             { "egy", "\u0c2a\u0c4d\u0c30\u0c3e\u0c1a\u0c40\u0c28 \u0c08\u0c1c\u0c3f\u0c2a\u0c4d\u0c37\u0c3f\u0c2f\u0c28\u0c4d" },
             { "raj", "\u0c30\u0c3e\u0c1c\u0c38\u0c4d\u0c24\u0c3e\u0c28\u0c40" },
             { "Phag", "\u0c2b\u0c3e\u0c17\u0c4d\u0c38\u0c4d-\u0c2a\u0c3e" },
@@ -291,7 +293,7 @@ public class LocaleNames_te extends OpenListResourceBundle {
             { "zxx", "\u0c32\u0c3f\u0c2a\u0c3f \u0c32\u0c47\u0c26\u0c41" },
             { "de_AT", "\u0c06\u0c38\u0c4d\u0c1f\u0c4d\u0c30\u0c3f\u0c2f\u0c28\u0c4d \u0c1c\u0c30\u0c4d\u0c2e\u0c28\u0c4d" },
             { "Vaii", metaValue_vai },
-            { "HK", "\u0c39\u0c3e\u0c02\u0c15\u0c3e\u0c02\u0c17\u0c4d \u0c0e\u0c38\u0c4d\u0c0f\u0c06\u0c30\u0c4d" },
+            { "HK", "\u0c39\u0c3e\u0c02\u0c15\u0c3e\u0c02\u0c17\u0c4d \u0c0e\u0c38\u0c4d\u0c0f\u0c06\u0c30\u0c4d \u0c1a\u0c48\u0c28\u0c3e" },
             { "HM", "\u0c39\u0c46\u0c30\u0c4d\u0c21\u0c4d \u0c26\u0c40\u0c35\u0c3f \u0c2e\u0c30\u0c3f\u0c2f\u0c41 \u0c2e\u0c46\u0c15\u0c4d\u200c\u0c21\u0c4a\u0c28\u0c3e\u0c32\u0c4d\u0c21\u0c4d \u0c26\u0c40\u0c35\u0c41\u0c32\u0c41" },
             { "HN", "\u0c39\u0c4b\u0c02\u0c21\u0c41\u0c30\u0c3e\u0c38\u0c4d" },
             { "HR", "\u0c15\u0c4d\u0c30\u0c4a\u0c2f\u0c47\u0c37\u0c3f\u0c2f\u0c3e" },
@@ -313,7 +315,7 @@ public class LocaleNames_te extends OpenListResourceBundle {
             { "IM", "\u0c10\u0c32\u0c4d \u0c06\u0c2b\u0c4d \u0c2e\u0c3e\u0c28\u0c4d" },
             { "IN", "\u0c2d\u0c3e\u0c30\u0c24\u0c26\u0c47\u0c36\u0c02" },
             { "type.co.eor", "\u0c2f\u0c41\u0c30\u0c4b\u0c2a\u0c3f\u0c2f\u0c28\u0c4d \u0c15\u0c4d\u0c30\u0c2e\u0c2c\u0c26\u0c4d\u0c27\u0c40\u0c15\u0c30\u0c23 \u0c28\u0c3f\u0c2c\u0c02\u0c27\u0c28\u0c32\u0c41" },
-            { "IO", "\u0c2c\u0c4d\u0c30\u0c3f\u0c1f\u0c40\u0c37\u0c4d \u0c39\u0c3f\u0c02\u0c26\u0c42 \u0c2e\u0c39\u0c3e\u0c38\u0c2e\u0c41\u0c26\u0c4d\u0c30 \u0c2a\u0c4d\u0c30\u0c3e\u0c02\u0c24\u0c02" },
+            { "IO", "\u0c2c\u0c4d\u0c30\u0c3f\u0c1f\u0c3f\u0c37\u0c4d \u0c39\u0c3f\u0c02\u0c26\u0c42 \u0c2e\u0c39\u0c3e\u0c38\u0c2e\u0c41\u0c26\u0c4d\u0c30 \u0c2a\u0c4d\u0c30\u0c3e\u0c02\u0c24\u0c02" },
             { "IQ", "\u0c07\u0c30\u0c3e\u0c15\u0c4d" },
             { "IR", "\u0c07\u0c30\u0c3e\u0c28\u0c4d" },
             { "IS", "\u0c10\u0c38\u0c4d\u0c32\u0c3e\u0c02\u0c21\u0c4d" },
@@ -389,7 +391,7 @@ public class LocaleNames_te extends OpenListResourceBundle {
             { "MH", "\u0c2e\u0c3e\u0c30\u0c4d\u0c37\u0c32\u0c4d \u0c26\u0c40\u0c35\u0c41\u0c32\u0c41" },
             { "ale", "\u0c05\u0c32\u0c3f\u0c2f\u0c41\u0c1f\u0c4d" },
             { "type.nu.vaii", "\u0c35\u0c3e\u0c2f\u0c4d \u0c05\u0c02\u0c15\u0c46\u0c32\u0c41" },
-            { "MK", "\u0c2e\u0c47\u0c38\u0c3f\u0c21\u0c4b\u0c28\u0c3f\u0c2f\u0c3e" },
+            { "MK", "\u0c09\u0c24\u0c4d\u0c24\u0c30 \u0c2e\u0c3e\u0c38\u0c3f\u0c21\u0c4b\u0c28\u0c3f\u0c2f\u0c3e" },
             { "ML", "\u0c2e\u0c3e\u0c32\u0c3f" },
             { "MM", "\u0c2e\u0c2f\u0c28\u0c4d\u0c2e\u0c3e\u0c30\u0c4d" },
             { "MN", "\u0c2e\u0c02\u0c17\u0c4b\u0c32\u0c3f\u0c2f\u0c3e" },
@@ -520,7 +522,7 @@ public class LocaleNames_te extends OpenListResourceBundle {
             { "SX", "\u0c38\u0c3f\u0c02\u0c1f\u0c4d \u0c2e\u0c3e\u0c30\u0c4d\u0c1f\u0c46\u0c28\u0c4d" },
             { "SY", "\u0c38\u0c3f\u0c30\u0c3f\u0c2f\u0c3e" },
             { "yao", "\u0c2f\u0c3e\u0c2f\u0c47" },
-            { "SZ", "\u0c38\u0c4d\u0c35\u0c3e\u0c1c\u0c3f\u0c32\u0c4d\u0c2f\u0c3e\u0c02\u0c21\u0c4d" },
+            { "SZ", "\u0c08\u0c38\u0c4d\u0c35\u0c3e\u0c1f\u0c3f\u0c28\u0c3f" },
             { "arw", "\u0c05\u0c30\u0c3e\u0c35\u0c3e\u0c15\u0c4d" },
             { "arz", "\u0c08\u0c1c\u0c3f\u0c2a\u0c4d\u0c37\u0c3f\u0c2f\u0c28\u0c4d \u0c05\u0c30\u0c2c\u0c3f\u0c15\u0c4d" },
             { "yap", "\u0c2f\u0c3e\u0c2a\u0c3f\u0c38\u0c4d" },
@@ -559,7 +561,7 @@ public class LocaleNames_te extends OpenListResourceBundle {
             { "sw_CD", "\u0c15\u0c3e\u0c02\u0c17\u0c4b \u0c38\u0c4d\u0c35\u0c3e\u0c39\u0c3f\u0c32\u0c3f" },
             { "034", "\u0c26\u0c15\u0c4d\u0c37\u0c3f\u0c23 \u0c06\u0c38\u0c3f\u0c2f\u0c3e" },
             { "hai", "\u0c39\u0c48\u0c21\u0c3e" },
-            { "035", "\u0c28\u0c48\u0c30\u0c41\u0c24\u0c3f \u0c06\u0c38\u0c3f\u0c2f\u0c3e" },
+            { "035", "\u0c06\u0c17\u0c4d\u0c28\u0c47\u0c2f \u0c06\u0c38\u0c3f\u0c2f\u0c3e" },
             { "UG", "\u0c09\u0c17\u0c3e\u0c02\u0c21\u0c3e" },
             { "hak", "\u0c39\u0c15\u0c4d\u0c15\u0c3e \u0c1a\u0c48\u0c28\u0c40\u0c38\u0c4d" },
             { "type.co.pinyin", "\u0c2a\u0c3f\u0c28\u0c4d\u200c\u0c2f\u0c3f\u0c28\u0c4d \u0c15\u0c4d\u0c30\u0c2e\u0c2c\u0c26\u0c4d\u0c27\u0c40\u0c15\u0c30\u0c23 \u0c15\u0c4d\u0c30\u0c2e\u0c02" },
@@ -600,7 +602,9 @@ public class LocaleNames_te extends OpenListResourceBundle {
             { "WS", "\u0c38\u0c2e\u0c4b\u0c35\u0c3e" },
             { "wal", "\u0c35\u0c3e\u0c32\u0c47\u0c1f\u0c4d\u0c1f\u0c3e" },
             { "was", "\u0c35\u0c3e\u0c37\u0c4b" },
+            { "XA", "\u0c38\u0c42\u0c21\u0c4b \u0c2f\u0c3e\u0c15\u0c4d\u0c38\u0c46\u0c02\u0c1f\u0c4d\u0c38\u0c4d" },
             { "war", "\u0c35\u0c3e\u0c30\u0c47" },
+            { "XB", "\u0c38\u0c42\u0c21\u0c4b-\u0c2c\u0c3f\u0c21\u0c3f" },
             { "awa", "\u0c05\u0c35\u0c27\u0c3f" },
             { "061", "\u0c2a\u0c3e\u0c32\u0c3f\u0c28\u0c47\u0c37\u0c3f\u0c2f\u0c3e" },
             { "XK", "\u0c15\u0c4a\u0c38\u0c4b\u0c35\u0c4b" },
@@ -1006,7 +1010,7 @@ public class LocaleNames_te extends OpenListResourceBundle {
             { "bua", "\u0c2c\u0c41\u0c30\u0c3f\u0c2f\u0c1f\u0c4d" },
             { "143", "\u0c2e\u0c27\u0c4d\u0c2f \u0c06\u0c38\u0c3f\u0c2f\u0c3e" },
             { "te", metaValue_te },
-            { "145", "\u0c2a\u0c21\u0c2e\u0c1f\u0c3f \u0c06\u0c38\u0c3f\u0c2f\u0c3e" },
+            { "145", "\u0c2a\u0c36\u0c4d\u0c1a\u0c3f\u0c2e \u0c06\u0c38\u0c3f\u0c2f\u0c3e" },
             { "tg", "\u0c24\u0c1c\u0c3f\u0c15\u0c4d" },
             { "th", metaValue_th },
             { "ti", "\u0c1f\u0c3f\u0c17\u0c4d\u0c30\u0c3f\u0c28\u0c4d\u0c2f\u0c3e" },
@@ -1020,9 +1024,9 @@ public class LocaleNames_te extends OpenListResourceBundle {
             { "dyo", "\u0c1c\u0c4b\u0c32\u0c3e-\u0c2b\u0c4b\u0c28\u0c2f\u0c3f" },
             { "type.nu.jpan", "\u0c1c\u0c2a\u0c3e\u0c28\u0c40\u0c2f\u0c41\u0c32 \u0c38\u0c02\u0c16\u0c4d\u0c2f\u0c32\u0c41" },
             { "tr", "\u0c1f\u0c30\u0c4d\u0c15\u0c3f\u0c37\u0c4d" },
+            { "Cakm", metaValue_ccp },
             { "ts", "\u0c38\u0c4b\u0c02\u0c17\u0c3e" },
             { "swb", "\u0c15\u0c4a\u0c2e\u0c4a\u0c30\u0c3f\u0c2f\u0c28\u0c4d" },
-            { "Cakm", "\u0c1a\u0c15\u0c4d\u0c2e\u0c3e" },
             { "tt", "\u0c1f\u0c3e\u0c1f\u0c30\u0c4d" },
             { "dyu", "\u0c21\u0c4d\u0c2f\u0c41\u0c32\u0c3e" },
             { "tw", "\u0c1f\u0c4d\u0c35\u0c3f" },
@@ -1144,6 +1148,7 @@ public class LocaleNames_te extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u0c24\u0c2e\u0c3f\u0c33 \u0c05\u0c02\u0c15\u0c46\u0c32\u0c41" },
             { "krc", "\u0c15\u0c30\u0c1a\u0c47-\u0c2c\u0c32\u0c4d\u0c15\u0c3e\u0c30\u0c4d" },
             { "inh", "\u0c07\u0c02\u0c17\u0c41\u0c37\u0c4d" },
+            { "fa_AF", "\u0c21\u0c3e\u0c30\u0c3f" },
             { "krl", "\u0c15\u0c30\u0c47\u0c32\u0c3f\u0c2f\u0c28\u0c4d" },
             { "efi", "\u0c0e\u0c2b\u0c3f\u0c15\u0c4d" },
             { "tcy", "\u0c24\u0c41\u0c33\u0c41" },
