@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -96,6 +96,7 @@ public class LocaleNames_yue_Hans extends OpenListResourceBundle {
         final String metaValue_bas = "\u5df4\u8428\u6587";
         final String metaValue_bax = "\u5df4\u59c6\u7a46\u6587";
         final String metaValue_bug = "\u5e03\u5409\u65af\u6587";
+        final String metaValue_ccp = "\u67e5\u514b\u9a6c\u6587";
         final String metaValue_chr = "\u67f4\u7f57\u57fa\u6587";
         final String metaValue_cop = "\u79d1\u666e\u7279\u6587";
         final String metaValue_mai = "\u8fc8\u8482\u5229\u6587";
@@ -120,6 +121,7 @@ public class LocaleNames_yue_Hans extends OpenListResourceBundle {
             { "Zsye", "\u8868\u60c5\u7b26\u53f7" },
             { "%%NJIVA", "\u96f7\u897f\u4e9a\u5c3c\u74e6\u65b9\u8a00" },
             { "xmf", "\u660e\u683c\u5217\u5c14\u6587" },
+            { "ccp", metaValue_ccp },
             { "egy", "\u53e4\u57c3\u53ca\u6587" },
             { "raj", "\u62c9\u8d3e\u65af\u5766\u8bf8\u6587" },
             { "Phag", "\u516b\u601d\u5df4\u6587" },
@@ -458,6 +460,7 @@ public class LocaleNames_yue_Hans extends OpenListResourceBundle {
             { "MZ", "\u83ab\u4e09\u6bd4\u514b" },
             { "Phli", "\u5df4\u5217\u7ef4\u6587\uff08\u7891\u94ed\u4f53\uff09" },
             { "NA", "\u7eb3\u7c73\u6bd4\u4e9a" },
+            { "202", "\u6492\u54c8\u62c9\u4ee5\u5357\u975e\u6d32" },
             { "type.ca.hebrew", "\u5e0c\u4f2f\u6765\u5386" },
             { "type.co.dictionary", "\u5b57\u5178\u6392\u5e8f" },
             { "NC", "\u65b0\u5580\u91cc\u591a\u5c3c\u4e9a" },
@@ -683,7 +686,9 @@ public class LocaleNames_yue_Hans extends OpenListResourceBundle {
             { "type.nu.mtei", "\u66fc\u5c3c\u666e\u5c14\u6570\u5b57" },
             { "wal", "\u74e6\u62c9\u83ab\u6587" },
             { "was", "\u74e6\u7ecd\u6587" },
+            { "XA", "\u4f2a\u53e3\u97f3" },
             { "war", "\u74e6\u745e\u6587" },
+            { "XB", "\u4f2a Bidi" },
             { "awa", "\u963f\u74e6\u6587" },
             { "061", "\u73bb\u91cc\u5c3c\u897f\u4e9a" },
             { "XK", "\u79d1\u7d22\u6c83" },
@@ -1177,9 +1182,9 @@ public class LocaleNames_yue_Hans extends OpenListResourceBundle {
             { "dyo", "\u6731\u62c9\u6587" },
             { "type.nu.jpan", "\u5c0f\u5199\u65e5\u6587\u6570\u5b57" },
             { "tr", "\u571f\u8033\u5176\u6587" },
+            { "Cakm", metaValue_ccp },
             { "ts", "\u7279\u677e\u52a0\u6587" },
             { "swb", "\u845b\u6469\u6587" },
-            { "Cakm", "\u67e5\u514b\u9a6c\u6587" },
             { "tt", "\u9791\u977c\u6587" },
             { "dyu", "\u8fea\u5c24\u62c9\u6587" },
             { "tw", "\u7279\u5a01\u6587" },
@@ -1337,6 +1342,7 @@ public class LocaleNames_yue_Hans extends OpenListResourceBundle {
             { "inh", "\u5370\u53e4\u4ec0\u6587" },
             { "krj", "\u57fa\u90a3\u6765\u963f\u6587" },
             { "kri", "\u585e\u62c9\u5229\u6602\u514b\u91cc\u5965\u5c14\u6587" },
+            { "fa_AF", "\u8fbe\u91cc\u6587" },
             { "krl", "\u5361\u7d2f\u5229\u963f\u6587" },
             { "efi", "\u57c3\u83f2\u514b\u6587" },
             { "tcy", "\u56fe\u5362\u6587" },
